package
Version:
v0.0.0-...-79b0fad
Opens a new window with list of versions in this module.
Published: Sep 21, 2019
License: GPL-3.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 5
Opens a new window with list of known importers.
Documentation
¶
InitLogger initilizes logging format and level
Password is just an example type implementing the Redactor interface. Any
time this is logged, the Redacted() function will be called.
func (p Password) Redacted() interface{}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.