package
Version:
v0.0.0-...-79b0fad
Opens a new window with list of versions in this module.
Published: Sep 21, 2019
License: GPL-3.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 2
Opens a new window with list of known importers.
Documentation
¶
type Slave struct {
Node *node.Node `json:"node"`
Cluster []node.Node `json:"cluster"`
Tasks []Task `json:"tasks"`
}
Marshal returns the JSON encoding of a node info.
type Task struct {
ID string `json:"id"`
Name string `json:"name"`
Status string `json:"status"`
}
Marshal returns the JSON encoding of a node info.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.